GromoreConfig class
GroMore 初始化配置
Constructors
-
GromoreConfig({String? androidAppId, String? androidAppName, String? iosAppId, String? iosAppName, bool debug = false, bool useMediation = true, Set<
GromoreAdType> enabledAdTypes = const <GromoreAdType>{GromoreAdType.splash, GromoreAdType.interstitial, GromoreAdType.fullscreenVideo, GromoreAdType.rewardVideo, GromoreAdType.native, GromoreAdType.drawNative, GromoreAdType.banner}, Map<String, dynamic> ? androidOptions, Map<String, dynamic> ? iosOptions, bool? enableLog, bool enableLogToFile = false}) -
构建初始化配置
const
Properties
- androidAppId → String?
-
Android AppId
final
- androidAppName → String?
-
Android AppName
final
-
androidOptions
→ Map<
String, dynamic> ? -
Android 平台扩展参数
final
- debug → bool
-
是否 Debug 模式
final
-
enabledAdTypes
→ Set<
GromoreAdType> -
启用的广告类型集合
final
- enableLog → bool?
-
是否启用日志(不传则 Debug 默认开、Release 默认关)
final
- enableLogToFile → bool
-
是否同时写入日志文件
写入时遵循当前日志级别阈值,而不是只写入单个级别
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iosAppId → String?
-
iOS AppId
final
- iosAppName → String?
-
iOS AppName
final
-
iosOptions
→ Map<
String, dynamic> ? -
iOS 平台扩展参数
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- useMediation → bool
-
是否启用聚合
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - 转为通道传输 Map
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited